summaryrefslogtreecommitdiffstats
path: root/src/ui/dialog/session-player.h
diff options
context:
space:
mode:
authorTed Gould <ted@gould.cx>2008-10-27 18:03:09 +0000
committerTed Gould <ted@canonical.com>2008-10-27 18:03:09 +0000
commit7dbe11bc23efa5f51a9b84e7d0f6dd16e63e0902 (patch)
tree7d3a2b95b84a03a19cb132cdf88bea0ab6dc4773 /src/ui/dialog/session-player.h
parentMerging from trunk (diff)
downloadinkscape-7dbe11bc23efa5f51a9b84e7d0f6dd16e63e0902.tar.gz
inkscape-7dbe11bc23efa5f51a9b84e7d0f6dd16e63e0902.zip
From trunk
(bzr r6885)
Diffstat (limited to 'src/ui/dialog/session-player.h')
-rw-r--r--src/ui/dialog/session-player.h22
1 files changed, 16 insertions, 6 deletions
diff --git a/src/ui/dialog/session-player.h b/src/ui/dialog/session-player.h
index fd2945bb0..52377a73f 100644
--- a/src/ui/dialog/session-player.h
+++ b/src/ui/dialog/session-player.h
@@ -1,11 +1,10 @@
/**
* Whiteboard session playback control dialog
*
* Authors:
* David Yip <yipdw@rose-hulman.edu>
*
* Copyright (c) 2005 Authors
- *
* Released under GNU GPL, read the file 'COPYING' for more information
*/
@@ -38,7 +37,7 @@ namespace Dialog {
class SessionPlaybackDialog : public Dialog {
public:
- SessionPlaybackDialog() : Dialog("dialogs.session_playback", SP_VERB_DIALOG_WHITEBOARD_SESSIONPLAYBACK)
+ SessionPlaybackDialog() : Dialog("/dialogs/session_playback", SP_VERB_DIALOG_WHITEBOARD_SESSIONPLAYBACK)
{
}
@@ -122,3 +121,14 @@ private:
}
#endif
+
+/*
+ Local Variables:
+ mode:c++
+ c-file-style:"stroustrup"
+ c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
+ indent-tabs-mode:nil
+ fill-column:99
+ End:
+*/
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
@@ -1,11 +1,10 @@
-/**
- * Whiteboard session playback control dialog
- *
- * Authors:
+/** @file
+ * @brief Whiteboard session playback control dialog
+ */
+/* Authors:
* David Yip <yipdw@rose-hulman.edu>
*